Class: SafetyKit::Models::AgentDecisionCreateAgentDecisionParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/safety_kit/models/agent_decision_create_agent_decision_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content_type:, decision:, policy_id:, reference_id:, action: nil, agent_type: nil, comment: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see SafetyKit::Models::AgentDecisionCreateAgentDecisionParams for more details.

Parameters:

  • content_type (String)

    The SafetyKit data namespace or content type for the content being reviewed

  • decision (String)

    The human reviewer’s verdict for the policy category.

  • policy_id (String)

    The SafetyKit policy category ID that was evaluated, as configured for your acco

  • reference_id (String)

    Stable identifier for the content object in your system

  • action (String) (defaults to: nil)

    Optional correct enforcement action for this content, such as ‘reduce_visibility

  • agent_type (String) (defaults to: nil)

    Optional type of review that produced this decision, such as ‘appeal’, ‘bpo_revi

  • comment (String, nil) (defaults to: nil)

    Additional context or details from the human reviewer

  • request_options (SafetyKit::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 55

Instance Attribute Details

#actionString?

Optional correct enforcement action for this content, such as ‘reduce_visibility’ or ‘unpublish’

Returns:

  • (String, nil)


40
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 40

optional :action, String

#agent_typeString?

Optional type of review that produced this decision, such as ‘appeal’, ‘bpo_review’, or ‘policy_expert’

Returns:

  • (String, nil)


47
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 47

optional :agent_type, String

#commentString?

Additional context or details from the human reviewer

Returns:

  • (String, nil)


53
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 53

optional :comment, String, nil?: true

#content_typeString

The SafetyKit data namespace or content type for the content being reviewed

Returns:

  • (String)


14
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 14

required :content_type, String

#decisionString

The human reviewer’s verdict for the policy category.

Returns:

  • (String)


20
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 20

required :decision, String

#policy_idString

The SafetyKit policy category ID that was evaluated, as configured for your account

Returns:

  • (String)


27
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 27

required :policy_id, String

#reference_idString

Stable identifier for the content object in your system

Returns:

  • (String)


33
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 33

required :reference_id, String