Class: SafetyKit::Models::AsyncCreateAsyncParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::AsyncCreateAsyncParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/safety_kit/models/async_create_async_params.rb,
sig/safety_kit/models/async_create_async_params.rbs
Overview
Defined Under Namespace
Modules: Body
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::SafetyKit
Instance Attribute Summary collapse
-
#body ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UserContactEventRequest, ...
Backend event or ordered batch of events to send to SafetyKit.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(body:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AsyncCreateAsyncParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(body:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::AsyncCreateAsyncParams for more details.
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 18
|
Instance Attribute Details
#body ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UserContactEventRequest, ...
Backend event or ordered batch of events to send to SafetyKit. Send events from your server after an action has happened in your product. Do not send these events directly from a browser or mobile client.
16 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 16 required :body, union: -> { SafetyKit::AsyncCreateAsyncParams::Body } |
Instance Method Details
#to_hash ⇒ {
18 |
# File 'sig/safety_kit/models/async_create_async_params.rbs', line 18
def to_hash: -> {
|