Class: SafetyKit::Models::AsyncCreateAsyncParams::Body::ContentUploadedEventRequest::ClientInfo
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::AsyncCreateAsyncParams::Body::ContentUploadedEventRequest::ClientInfo
- Defined in:
- lib/safety_kit/models/async_create_async_params.rb,
sig/safety_kit/models/async_create_async_params.rbs
Overview
Instance Attribute Summary collapse
-
#ip ⇒ String?
IP address observed by your backend for the client that triggered the event.
Instance Method Summary collapse
-
#initialize ⇒ ClientInfo
constructor
A new instance of ClientInfo.
- #to_hash ⇒ { ip: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ ClientInfo
Returns a new instance of ClientInfo.
560 |
# File 'sig/safety_kit/models/async_create_async_params.rbs', line 560
def initialize: (?ip: String) -> void
|
Instance Attribute Details
#ip ⇒ String?
IP address observed by your backend for the client that triggered the event.
699 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 699 optional :ip, String |
Instance Method Details
#to_hash ⇒ { ip: String }
562 |
# File 'sig/safety_kit/models/async_create_async_params.rbs', line 562
def to_hash: -> { ip: String }
|