Class: SafetyKit::Models::AsyncCreateAsyncParams::Body::ProductChangedEventRequest::Product

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/safety_kit/models/async_create_async_params.rb

Overview

See Also:

Defined Under Namespace

Classes: DiscountedPrice, Price, ShippingInfo

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, currency:) ⇒ Object

Discounted price of the product, when a discount applies.

Parameters:

  • amount (String)

    Price amount as a decimal string.

  • currency (String)

    ISO 4217 currency code.



# File 'lib/safety_kit/models/async_create_async_params.rb', line 1113

Instance Attribute Details

#discounted_priceSafetyKit::Models::AsyncCreateAsyncParams::Body::ProductChangedEventRequest::Product::DiscountedPrice?

Discounted price of the product, when a discount applies.



1103
1104
# File 'lib/safety_kit/models/async_create_async_params.rb', line 1103

optional :discounted_price,
-> { SafetyKit::AsyncCreateAsyncParams::Body::ProductChangedEventRequest::Product::DiscountedPrice }

#priceSafetyKit::Models::AsyncCreateAsyncParams::Body::ProductChangedEventRequest::Product::Price

Current listed price of the product.



1096
1097
# File 'lib/safety_kit/models/async_create_async_params.rb', line 1096

required :price,
-> { SafetyKit::AsyncCreateAsyncParams::Body::ProductChangedEventRequest::Product::Price }

#shipping_infoSafetyKit::Models::AsyncCreateAsyncParams::Body::ProductChangedEventRequest::Product::ShippingInfo?

Shipping details for the product.



1110
1111
# File 'lib/safety_kit/models/async_create_async_params.rb', line 1110

optional :shipping_info,
-> { SafetyKit::AsyncCreateAsyncParams::Body::ProductChangedEventRequest::Product::ShippingInfo }