Module: SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/safety_kit/models/async_create_async_params.rb
Overview
A user contacts, transacts with, or otherwise interacts with another user.
Defined Under Namespace
Classes: ContentUploaded, CreateAccount, ModerationDecision, ProductChanged, UpdateAccount, UserContact, UserReport
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(type:, value:) ⇒ Object
Some parameter documentations has been truncated, see UserReport::ResourcesUsed::UnionMember1 for more details.
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::UserReport::ResourcesUsed::EntityIDResource, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::UserReport::ResourcesUsed::UnionMember1)
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3380
|
Instance Method Details
#initialize(type:, value:) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::UserReport::ResourcesUsed::UnionMember1 for more details.
Real-world or account resource used during the event, such as an email, phone number, address, URL, social handle, or payment identifier.
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3367
|