Class: SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded
- Defined in:
- lib/safety_kit/models/async_create_async_params.rb
Defined Under Namespace
Modules: Content, Metadata, ResourcesUsed Classes: ClientInfo
Instance Attribute Summary collapse
-
#client_info ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
-
#content ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::Content::EventImageContent>
User-authored or user-uploaded content parts.
-
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
-
#event_name ⇒ String
Stable, low-cardinality product action name.
-
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging.
-
#resources_used ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::ResourcesUsed::EntityIDResource, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event.
-
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
- #type ⇒ Symbol, :content_uploaded
-
#user_id ⇒ String
Your stable canonical identifier for the user or account.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::Content::EventImageContent)
Instance Method Summary collapse
-
#initialize(ip: nil) ⇒ Object
constructor
Client context observed by your backend for the user action that triggered the event.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ip: nil) ⇒ Object
Client context observed by your backend for the user action that triggered the event.
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3458
|
Instance Attribute Details
#client_info ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
3424 3425 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3424 optional :client_info, -> { SafetyKit::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::ClientInfo } |
#content ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::Content::EventImageContent>
User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.
3392 3393 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3392 required :content, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::Content] } |
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
3432 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3432 optional :content_id, String |
#event_name ⇒ String
Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.
3400 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3400 required :event_name, String |
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent. Reuse the same key only for retries of the same logical event.
3439 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3439 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.
3446 3447 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3446 optional :metadata, -> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::Metadata] } |
#resources_used ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::ResourcesUsed::EntityIDResource, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, caller-defined ids, or similar identifiers.
3455 3456 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3455 optional :resources_used, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::ResourcesUsed] } |
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
3406 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3406 required :timestamp, Time |
#type ⇒ Symbol, :content_uploaded
3411 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3411 required :type, const: :content_uploaded |
#user_id ⇒ String
Your stable canonical identifier for the user or account.
3417 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3417 required :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3610
|
.variants ⇒ Array(SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ContentUploaded::Content::EventImageContent)
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3615
|