Class: SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged
- Defined in:
- lib/safety_kit/models/async_create_async_params.rb
Defined Under Namespace
Modules: Content, EventName, Metadata, ResourcesUsed Classes: ClientInfo, Product
Instance Attribute Summary collapse
-
#client_info ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
-
#content ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::Content::EventImageContent>
User-authored or user-uploaded content parts.
-
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
-
#event_name ⇒ Symbol, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::EventName
Product action that triggered this event.
-
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging.
-
#product ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::Product
Commerce details for the product involved in this event.
-
#resources_used ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::ResourcesUsed::EntityIDResource, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event.
-
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
- #type ⇒ Symbol, :product_changed
-
#user_id ⇒ String
Your stable canonical identifier for the user or account.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::Content::EventImageContent)
Instance Method Summary collapse
-
#initialize(ip: nil) ⇒ Object
constructor
Client context observed by your backend for the user action that triggered the event.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ip: nil) ⇒ Object
Client context observed by your backend for the user action that triggered the event.
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3840
|
Instance Attribute Details
#client_info ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
3806 3807 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3806 optional :client_info, -> { SafetyKit::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::ClientInfo } |
#content ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::Content::EventImageContent>
User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.
3768 3769 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3768 required :content, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::Content] } |
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
3814 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3814 optional :content_id, String |
#event_name ⇒ Symbol, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::EventName
Product action that triggered this event.
3775 3776 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3775 required :event_name, enum: -> { SafetyKit::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::EventName } |
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent. Reuse the same key only for retries of the same logical event.
3821 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3821 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.
3828 3829 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3828 optional :metadata, -> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::Metadata] } |
#product ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::Product
Commerce details for the product involved in this event.
3782 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3782 required :product, -> { SafetyKit::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::Product } |
#resources_used ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::ResourcesUsed::EntityIDResource, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, caller-defined ids, or similar identifiers.
3837 3838 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3837 optional :resources_used, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::ResourcesUsed] } |
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
3788 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3788 required :timestamp, Time |
#type ⇒ Symbol, :product_changed
3793 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3793 required :type, const: :product_changed |
#user_id ⇒ String
Your stable canonical identifier for the user or account.
3799 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3799 required :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3994
|
.variants ⇒ Array(SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember7::ProductChanged::Content::EventImageContent)
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 3999
|