Class: SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged
- Defined in:
- lib/safety_kit/models/async_create_async_params.rb,
sig/safety_kit/models/async_create_async_params.rbs
Defined Under Namespace
Modules: Content, EventName, Metadata, ResourcesUsed Classes: ClientInfo, Product
Instance Attribute Summary collapse
-
#client_info ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
-
#content ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::Content::EventImageContent>
User-authored or user-uploaded content parts.
-
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
-
#event_name ⇒ Symbol, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::EventName
Product action that triggered this event.
-
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging.
-
#product ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::Product
Commerce details for the product involved in this event.
-
#resources_used ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::ResourcesUsed::EntityIDResource, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event.
-
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
- #type ⇒ Symbol, :product_changed
-
#user_id ⇒ String
Your stable canonical identifier for the user or account.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::Content::EventImageContent)
Instance Method Summary collapse
-
#initialize(ip: nil) ⇒ Object
constructor
Client context observed by your backend for the user action that triggered the event.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ip: nil) ⇒ Object
Client context observed by your backend for the user action that triggered the event.
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4243
|
Instance Attribute Details
#client_info ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
4209 4210 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4209 optional :client_info, -> { SafetyKit::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::ClientInfo } |
#content ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::Content::EventImageContent>
User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.
4171 4172 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4171 required :content, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::Content] } |
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
4217 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4217 optional :content_id, String |
#event_name ⇒ Symbol, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::EventName
Product action that triggered this event.
4178 4179 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4178 required :event_name, enum: -> { SafetyKit::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::EventName } |
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent. Reuse the same key only for retries of the same logical event.
4224 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4224 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.
4231 4232 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4231 optional :metadata, -> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::Metadata] } |
#product ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::Product
Commerce details for the product involved in this event.
4185 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4185 required :product, -> { SafetyKit::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::Product } |
#resources_used ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::ResourcesUsed::EntityIDResource, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, caller-defined ids, or similar identifiers.
4240 4241 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4240 optional :resources_used, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::ResourcesUsed] } |
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
4191 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4191 required :timestamp, Time |
#type ⇒ Symbol, :product_changed
4196 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4196 required :type, const: :product_changed |
#user_id ⇒ String
Your stable canonical identifier for the user or account.
4202 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4202 required :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4397
|
.variants ⇒ Array(SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::ProductChanged::Content::EventImageContent)
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 4402
|
Instance Method Details
#to_hash ⇒ {
3301 |
# File 'sig/safety_kit/models/async_create_async_params.rbs', line 3301
def to_hash: -> {
|