Class: SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount
- Defined in:
- lib/safety_kit/models/async_create_async_params.rb,
sig/safety_kit/models/async_create_async_params.rbs
Defined Under Namespace
Modules: Content, Metadata, ResourcesUsed Classes: ClientInfo
Instance Attribute Summary collapse
-
#client_info ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
-
#content ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::Content::EventImageContent>?
User-authored or user-uploaded content parts.
-
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
-
#event_name ⇒ String
Stable, low-cardinality product action name.
-
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging.
-
#resources_used ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::ResourcesUsed::EntityIDResource, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event.
-
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
- #type ⇒ Symbol, :update_account
-
#user_id ⇒ String
Your stable canonical identifier for the user or account.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::Content::EventImageContent)
Instance Method Summary collapse
-
#initialize(ip: nil) ⇒ Object
constructor
Client context observed by your backend for the user action that triggered the event.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ip: nil) ⇒ Object
Client context observed by your backend for the user action that triggered the event.
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 5109
|
Instance Attribute Details
#client_info ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
5066 5067 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 5066 optional :client_info, -> { SafetyKit::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::ClientInfo } |
#content ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::Content::EventImageContent>?
User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.
5075 5076 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 5075 optional :content, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::Content] } |
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
5083 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 5083 optional :content_id, String |
#event_name ⇒ String
Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.
5042 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 5042 required :event_name, String |
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent. Reuse the same key only for retries of the same logical event.
5090 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 5090 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.
5097 5098 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 5097 optional :metadata, -> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::Metadata] } |
#resources_used ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::ResourcesUsed::EntityIDResource, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, caller-defined ids, or similar identifiers.
5106 5107 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 5106 optional :resources_used, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::ResourcesUsed] } |
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
5048 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 5048 required :timestamp, Time |
#type ⇒ Symbol, :update_account
5053 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 5053 required :type, const: :update_account |
#user_id ⇒ String
Your stable canonical identifier for the user or account.
5059 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 5059 required :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 5277
|
.variants ⇒ Array(SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UnionMember8::UpdateAccount::Content::EventImageContent)
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 5282
|
Instance Method Details
#to_hash ⇒ {
3981 |
# File 'sig/safety_kit/models/async_create_async_params.rbs', line 3981
def to_hash: -> {
|