Class: SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest
- Defined in:
- lib/safety_kit/models/async_create_async_params.rb,
sig/safety_kit/models/async_create_async_params.rbs
Defined Under Namespace
Modules: Content, Metadata, ResourcesUsed, Type Classes: ClientInfo
Instance Attribute Summary collapse
-
#client_info ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
-
#content ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventImageContent>?
User-authored or user-uploaded content parts.
-
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
-
#event_name ⇒ String
Stable, low-cardinality product action name.
-
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent.
-
#labels ⇒ Array<String>
One or more label categories supplied with the report or moderation decision.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging.
-
#resources_used ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::EntityIDResource, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event.
-
#target_content_id ⇒ String?
Your stable identifier for the content being reported.
-
#target_user_id ⇒ String?
Your stable canonical identifier for the user being reported.
-
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
- #type ⇒ Symbol, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Type
-
#user_id ⇒ String
Your stable canonical identifier for the user or account.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventImageContent)
Instance Method Summary collapse
-
#initialize(ip: nil) ⇒ Object
constructor
Client context observed by your backend for the user action that triggered the event.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ip: nil) ⇒ Object
Client context observed by your backend for the user action that triggered the event.
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2207
|
Instance Attribute Details
#client_info ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
2153 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2153 optional :client_info, -> { SafetyKit::AsyncCreateAsyncParams::Body::UserReportEventRequest::ClientInfo } |
#content ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventImageContent>?
User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.
2161 2162 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2161 optional :content, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content] } |
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
2169 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2169 optional :content_id, String |
#event_name ⇒ String
Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.
2123 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2123 required :event_name, String |
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent. Reuse the same key only for retries of the same logical event.
2176 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2176 optional :idempotency_key, String |
#labels ⇒ Array<String>
One or more label categories supplied with the report or moderation decision.
2129 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2129 required :labels, SafetyKit::Internal::Type::ArrayOf[String] |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.
2183 2184 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2183 optional :metadata, -> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UserReportEventRequest::Metadata] } |
#resources_used ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::EntityIDResource, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, caller-defined ids, or similar identifiers.
2192 2193 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2192 optional :resources_used, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed] } |
#target_content_id ⇒ String?
Your stable identifier for the content being reported.
2199 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2199 optional :target_content_id, String |
#target_user_id ⇒ String?
Your stable canonical identifier for the user being reported.
2205 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2205 optional :target_user_id, String |
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
2135 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2135 required :timestamp, Time |
#type ⇒ Symbol, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Type
2140 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2140 required :type, enum: -> { SafetyKit::AsyncCreateAsyncParams::Body::UserReportEventRequest::Type } |
#user_id ⇒ String
Your stable canonical identifier for the user or account.
2146 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2146 required :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2249
|
.variants ⇒ Array(SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventImageContent)
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2398
|
Instance Method Details
#to_hash ⇒ {
1734 |
# File 'sig/safety_kit/models/async_create_async_params.rbs', line 1734
def to_hash: -> {
|