Class: SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::EntityIDResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::EntityIDResource
- Defined in:
- lib/safety_kit/models/async_create_async_params.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#namespace ⇒ String
Caller-defined namespace for the identifier.
-
#type ⇒ Symbol, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::EntityIDResource::Type
Caller-defined entity identifier resource.
-
#value ⇒ String
Identifier value within namespace.
Instance Method Summary collapse
-
#initialize(namespace:, type:, value:) ⇒ Object
constructor
Some parameter documentations has been truncated, see EntityIDResource for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(namespace:, type:, value:) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::EntityIDResource for more details.
Caller-defined stable entity identifier resource. This is equivalent to an id resource value of urlEncode(namespace) + ‘/’ + urlEncode(value).
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2465
|
Instance Attribute Details
#namespace ⇒ String
Caller-defined namespace for the identifier. SafetyKit stores this with value as urlEncode(namespace) + ‘/’ + urlEncode(value).
2449 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2449 required :namespace, String |
#type ⇒ Symbol, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::EntityIDResource::Type
Caller-defined entity identifier resource.
2455 2456 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2455 required :type, enum: -> { SafetyKit::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::EntityIDResource::Type } |
#value ⇒ String
Identifier value within namespace. SafetyKit stores a normalized hash of the encoded namespace/value pair, not the raw value.
2463 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2463 required :value, String |