Class: SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded::ResourcesUsed
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded::ResourcesUsed
- Defined in:
- lib/safety_kit/models/beta/event_create_params.rb
Instance Attribute Summary collapse
-
#type ⇒ String
Resource family, such as email, phone, name, address, url, instagram, tiktok, youtube, linkedin, or another stable snake_case identifier.
-
#value ⇒ String
Resource value used during the event.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from SafetyKit::Internal::Type::BaseModel
Instance Attribute Details
#type ⇒ String
Resource family, such as email, phone, name, address, url, instagram, tiktok, youtube, linkedin, or another stable snake_case identifier.
572 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 572 required :type, String |
#value ⇒ String
Resource value used during the event. SafetyKit stores a normalized hash of this value, not the raw value.
579 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 579 required :value, String |