Class: SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::CreateAccount

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/safety_kit/models/beta/event_create_params.rb

Defined Under Namespace

Modules: Content, Metadata Classes: ResourcesUsed

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_name:, timestamp:, user_id:, content: nil, metadata: nil, resources_used: nil, type: :create_account) ⇒ Object

Some parameter documentations has been truncated, see SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::CreateAccount for more details.

A user or account is created.

Parameters:



# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1789

Instance Attribute Details

#contentArray<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::CreateAccount::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::CreateAccount::Content::EventImageContent>?

User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.



1769
1770
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1769

optional :content,
-> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::Beta::EventCreateParams::Body::UnionMember4::CreateAccount::Content] }

#event_nameString

Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.

Returns:

  • (String)


1744
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1744

required :event_name, String

#metadataHash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?

Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.

Returns:

  • (Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}, nil)


1777
1778
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1777

optional :metadata,
-> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::Beta::EventCreateParams::Body::UnionMember4::CreateAccount::Metadata] }

#resources_usedArray<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::CreateAccount::ResourcesUsed>?

Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, or similar identifiers.



1786
1787
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1786

optional :resources_used,
-> { SafetyKit::Internal::Type::ArrayOf[SafetyKit::Beta::EventCreateParams::Body::UnionMember4::CreateAccount::ResourcesUsed] }

#timestampTime

The time the event occurred in your system, as an ISO 8601 datetime string.

Returns:

  • (Time)


1750
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1750

required :timestamp, Time

#typeSymbol, :create_account

Returns:

  • (Symbol, :create_account)


1755
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1755

required :type, const: :create_account

#user_idString

Your stable canonical identifier for the user or account.

Returns:

  • (String)


1761
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1761

required :user_id, String