Class: SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::UserContact
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::UserContact
- Defined in:
- lib/safety_kit/models/beta/event_create_params.rb
Defined Under Namespace
Modules: Content, Metadata Classes: ResourcesUsed
Instance Attribute Summary collapse
-
#content ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::UserContact::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::UserContact::Content::EventImageContent>?
User-authored or user-uploaded content parts.
-
#counterparty_user_id ⇒ String
Your stable canonical identifier for the other user in a user-to-user interaction.
-
#event_name ⇒ String
Stable, low-cardinality product action name.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging.
-
#resources_used ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::UserContact::ResourcesUsed>?
Reusable resources observed during the event.
-
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
- #type ⇒ Symbol, :user_contact
-
#user_id ⇒ String
Your stable canonical identifier for the user or account.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::UserContact::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::UserContact::Content::EventImageContent)
Instance Method Summary collapse
-
#initialize(counterparty_user_id:, event_name:, timestamp:, user_id:, content: nil, metadata: nil, resources_used: nil, type: :user_contact) ⇒ Object
constructor
Some parameter documentations has been truncated, see UserContact for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(counterparty_user_id:, event_name:, timestamp:, user_id:, content: nil, metadata: nil, resources_used: nil, type: :user_contact) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::UserContact for more details.
A user contacts, transacts with, or otherwise interacts with another user.
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1249
|
Instance Attribute Details
#content ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::UserContact::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::UserContact::Content::EventImageContent>?
User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.
1229 1230 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1229 optional :content, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::Beta::EventCreateParams::Body::UnionMember4::UserContact::Content] } |
#counterparty_user_id ⇒ String
Your stable canonical identifier for the other user in a user-to-user interaction.
1197 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1197 required :counterparty_user_id, String |
#event_name ⇒ String
Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.
1204 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1204 required :event_name, String |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.
1237 1238 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1237 optional :metadata, -> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::Beta::EventCreateParams::Body::UnionMember4::UserContact::Metadata] } |
#resources_used ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::UserContact::ResourcesUsed>?
Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, or similar identifiers.
1246 1247 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1246 optional :resources_used, -> { SafetyKit::Internal::Type::ArrayOf[SafetyKit::Beta::EventCreateParams::Body::UnionMember4::UserContact::ResourcesUsed] } |
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
1210 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1210 required :timestamp, Time |
#type ⇒ Symbol, :user_contact
1215 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1215 required :type, const: :user_contact |
#user_id ⇒ String
Your stable canonical identifier for the user or account.
1221 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1221 required :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1397
|
.variants ⇒ Array(SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::UserContact::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::UserContact::Content::EventImageContent)
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1402
|