Class: SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember5::UserContact

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/safety_kit/models/beta/event_create_params.rb

Defined Under Namespace

Modules: Content, Metadata Classes: ResourcesUsed

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_name:, target_user_id:, timestamp:, user_id:, content: nil, content_id: nil, idempotency_key: nil, metadata: nil, resources_used: nil, type: :user_contact) ⇒ Object

Some parameter documentations has been truncated, see SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember5::UserContact for more details.

A user contacts, transacts with, or otherwise interacts with another user.

Parameters:



# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1679

Instance Attribute Details

#contentArray<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember5::UserContact::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember5::UserContact::Content::EventImageContent>?

User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.



1645
1646
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1645

optional :content,
-> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::Beta::EventCreateParams::Body::UnionMember5::UserContact::Content] }

#content_idString?

Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.

Returns:

  • (String, nil)


1653
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1653

optional :content_id, String

#event_nameString

Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.

Returns:

  • (String)


1613
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1613

required :event_name, String

#idempotency_keyString?

Optional caller-provided key used to make retries of this individual event idempotent. Reuse the same key only for retries of the same logical event.

Returns:

  • (String, nil)


1660
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1660

optional :idempotency_key, String

#metadataHash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?

Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.

Returns:

  • (Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}, nil)


1667
1668
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1667

optional :metadata,
-> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::Beta::EventCreateParams::Body::UnionMember5::UserContact::Metadata] }

#resources_usedArray<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember5::UserContact::ResourcesUsed>?

Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, or similar identifiers.



1676
1677
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1676

optional :resources_used,
-> { SafetyKit::Internal::Type::ArrayOf[SafetyKit::Beta::EventCreateParams::Body::UnionMember5::UserContact::ResourcesUsed] }

#target_user_idString

Your stable canonical identifier for the other user in a user-to-user interaction.

Returns:

  • (String)


1620
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1620

required :target_user_id, String

#timestampTime

The time the event occurred in your system, as an ISO 8601 datetime string.

Returns:

  • (Time)


1626
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1626

required :timestamp, Time

#typeSymbol, :user_contact

Returns:

  • (Symbol, :user_contact)


1631
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1631

required :type, const: :user_contact

#user_idString

Your stable canonical identifier for the user or account.

Returns:

  • (String)


1637
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1637

required :user_id, String