Class: SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::UserReport

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/safety_kit/models/beta/event_create_params.rb

Defined Under Namespace

Modules: Content, Metadata Classes: ResourcesUsed

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_name:, labels:, timestamp:, user_id:, content: nil, content_id: nil, idempotency_key: nil, metadata: nil, resources_used: nil, target_content_id: nil, target_user_id: nil, type: :user_report) ⇒ Object

Some parameter documentations has been truncated, see SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::UserReport for more details.

A user-submitted report. Use user_id for the reporter. Include target_user_id when a user is reported, target_content_id when content is reported, and both when the report is about content associated with a user. Use content and content_id for the report itself.

Parameters:

  • event_name (String)

    Stable, low-cardinality product action name. Use snake_case and put dynamic valu

  • labels (Array<String>)

    One or more label categories supplied with the report or moderation decision.

  • timestamp (Time)

    The time the event occurred in your system, as an ISO 8601 datetime string.

  • user_id (String)

    Your stable canonical identifier for the user or account.

  • content (Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::UserReport::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::UserReport::Content::EventImageContent>) (defaults to: nil)

    User-authored or user-uploaded content parts. Use this for message bodies, bios,

  • content_id (String) (defaults to: nil)

    Your stable identifier for the content involved in this event, such as a message

  • idempotency_key (String) (defaults to: nil)

    Optional caller-provided key used to make retries of this individual event idemp

  • metadata (Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}) (defaults to: nil)

    Non-PII product context for filtering, segmentation, and debugging. Values may b

  • resources_used (Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::UserReport::ResourcesUsed>) (defaults to: nil)

    Reusable resources observed during the event. Use this for emails, phone numbers

  • target_content_id (String) (defaults to: nil)

    Your stable identifier for the content being reported.

  • target_user_id (String) (defaults to: nil)

    Your stable canonical identifier for the user being reported.

  • type (Symbol, :user_report) (defaults to: :user_report)


# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3199

Instance Attribute Details

#contentArray<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::UserReport::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::UserReport::Content::EventImageContent>?

User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.



3153
3154
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3153

optional :content,
-> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::Beta::EventCreateParams::Body::UnionMember6::UserReport::Content] }

#content_idString?

Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.

Returns:

  • (String, nil)


3161
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3161

optional :content_id, String

#event_nameString

Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.

Returns:

  • (String)


3122
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3122

required :event_name, String

#idempotency_keyString?

Optional caller-provided key used to make retries of this individual event idempotent. Reuse the same key only for retries of the same logical event.

Returns:

  • (String, nil)


3168
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3168

optional :idempotency_key, String

#labelsArray<String>

One or more label categories supplied with the report or moderation decision.

Returns:

  • (Array<String>)


3128
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3128

required :labels, SafetyKit::Internal::Type::ArrayOf[String]

#metadataHash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?

Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.

Returns:

  • (Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}, nil)


3175
3176
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3175

optional :metadata,
-> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::Beta::EventCreateParams::Body::UnionMember6::UserReport::Metadata] }

#resources_usedArray<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::UserReport::ResourcesUsed>?

Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, or similar identifiers.



3184
3185
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3184

optional :resources_used,
-> { SafetyKit::Internal::Type::ArrayOf[SafetyKit::Beta::EventCreateParams::Body::UnionMember6::UserReport::ResourcesUsed] }

#target_content_idString?

Your stable identifier for the content being reported.

Returns:

  • (String, nil)


3191
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3191

optional :target_content_id, String

#target_user_idString?

Your stable canonical identifier for the user being reported.

Returns:

  • (String, nil)


3197
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3197

optional :target_user_id, String

#timestampTime

The time the event occurred in your system, as an ISO 8601 datetime string.

Returns:

  • (Time)


3134
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3134

required :timestamp, Time

#typeSymbol, :user_report

Returns:

  • (Symbol, :user_report)


3139
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3139

required :type, const: :user_report

#user_idString

Your stable canonical identifier for the user or account.

Returns:

  • (String)


3145
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3145

required :user_id, String