Class: SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/safety_kit/models/beta/event_create_params.rb

Overview

See Also:

Defined Under Namespace

Classes: DiscountedPrice, Price, ShippingInfo

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, currency:) ⇒ Object

Discounted price of the product, when a discount applies.

Parameters:

  • amount (String)

    Price amount as a decimal string.

  • currency (String)

    ISO 4217 currency code.



# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3232

Instance Attribute Details

#discounted_priceSafetyKit::Models::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product::DiscountedPrice?

Discounted price of the product, when a discount applies.



3222
3223
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3222

optional :discounted_price,
-> { SafetyKit::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product::DiscountedPrice }

#priceSafetyKit::Models::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product::Price

Current listed price of the product.



3215
3216
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3215

required :price,
-> { SafetyKit::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product::Price }

#shipping_infoSafetyKit::Models::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product::ShippingInfo?

Shipping details for the product.



3229
3230
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3229

optional :shipping_info,
-> { SafetyKit::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product::ShippingInfo }