Class: SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal
- Defined in:
- lib/safety_kit/models/beta/event_create_params.rb,
sig/safety_kit/models/beta/event_create_params.rbs
Defined Under Namespace
Modules: Content, Metadata, ResourcesUsed Classes: ClientInfo
Instance Attribute Summary collapse
-
#appealed_decision_id ⇒ String?
Your stable identifier for the moderation decision or enforcement action being appealed, such as the content_id of a moderation_decision event you previously sent.
-
#client_info ⇒ SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
-
#content ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::Content::EventImageContent>?
User-authored or user-uploaded content parts.
-
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
-
#event_name ⇒ String
Stable, low-cardinality product action name.
-
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging.
-
#resources_used ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::ResourcesUsed::EntityIDResource, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event.
-
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
- #type ⇒ Symbol, :appeal
-
#user_id ⇒ String
Your stable canonical identifier for the user or account.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::Content::EventImageContent)
Instance Method Summary collapse
-
#initialize(ip: nil) ⇒ Object
constructor
Client context observed by your backend for the user action that triggered the event.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ip: nil) ⇒ Object
Client context observed by your backend for the user action that triggered the event.
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 5899
|
Instance Attribute Details
#appealed_decision_id ⇒ String?
Your stable identifier for the moderation decision or enforcement action being appealed, such as the content_id of a moderation_decision event you previously sent.
5850 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 5850 optional :appealed_decision_id, String |
#client_info ⇒ SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
5857 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 5857 optional :client_info, -> { SafetyKit::Beta::EventCreateParams::Body::UnionMember8::Appeal::ClientInfo } |
#content ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::Content::EventImageContent>?
User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.
5865 5866 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 5865 optional :content, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::Beta::EventCreateParams::Body::UnionMember8::Appeal::Content] } |
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
5873 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 5873 optional :content_id, String |
#event_name ⇒ String
Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.
5825 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 5825 required :event_name, String |
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent. Reuse the same key only for retries of the same logical event.
5880 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 5880 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.
5887 5888 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 5887 optional :metadata, -> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::Beta::EventCreateParams::Body::UnionMember8::Appeal::Metadata] } |
#resources_used ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::ResourcesUsed::EntityIDResource, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, caller-defined ids, or similar identifiers.
5896 5897 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 5896 optional :resources_used, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::Beta::EventCreateParams::Body::UnionMember8::Appeal::ResourcesUsed] } |
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
5831 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 5831 required :timestamp, Time |
#type ⇒ Symbol, :appeal
5836 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 5836 required :type, const: :appeal |
#user_id ⇒ String
Your stable canonical identifier for the user or account.
5842 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 5842 required :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 6070
|
.variants ⇒ Array(SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember8::Appeal::Content::EventImageContent)
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 6075
|
Instance Method Details
#to_hash ⇒ {
4600 |
# File 'sig/safety_kit/models/beta/event_create_params.rbs', line 4600
def to_hash: -> {
|