Class: SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount
- Defined in:
- lib/safety_kit/models/beta/event_create_params.rb
Defined Under Namespace
Modules: Content, Metadata Classes: ResourcesUsed
Instance Attribute Summary collapse
-
#content ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::Content::EventImageContent>?
User-authored or user-uploaded content parts.
-
#event_name ⇒ String
Stable, low-cardinality product action name.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging.
-
#resources_used ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::ResourcesUsed>?
Reusable resources observed during the event.
-
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
- #type ⇒ Symbol, :update_account
-
#user_id ⇒ String
Your stable canonical identifier for the user or account.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::Content::EventImageContent)
Instance Method Summary collapse
-
#initialize(event_name:, timestamp:, user_id:, content: nil, metadata: nil, resources_used: nil, type: :update_account) ⇒ Object
constructor
Some parameter documentations has been truncated, see UpdateAccount for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(event_name:, timestamp:, user_id:, content: nil, metadata: nil, resources_used: nil, type: :update_account) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount for more details.
A user or account profile, contact detail, payment detail, or public bio changes.
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 915
|
Instance Attribute Details
#content ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::Content::EventImageContent>?
User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.
895 896 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 895 optional :content, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::Beta::EventCreateParams::Body::UpdateAccount::Content] } |
#event_name ⇒ String
Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.
870 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 870 required :event_name, String |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.
903 904 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 903 optional :metadata, -> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::Beta::EventCreateParams::Body::UpdateAccount::Metadata] } |
#resources_used ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::ResourcesUsed>?
Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, or similar identifiers.
912 913 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 912 optional :resources_used, -> { SafetyKit::Internal::Type::ArrayOf[SafetyKit::Beta::EventCreateParams::Body::UpdateAccount::ResourcesUsed] } |
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
876 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 876 required :timestamp, Time |
#type ⇒ Symbol, :update_account
881 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 881 required :type, const: :update_account |
#user_id ⇒ String
Your stable canonical identifier for the user or account.
887 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 887 required :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1062
|
.variants ⇒ Array(SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::Content::EventImageContent)
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1067
|