Class: SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::ResourcesUsed

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/safety_kit/models/beta/event_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, value:) ⇒ Object

Some parameter documentations has been truncated, see SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::ResourcesUsed for more details.

Real-world or account resource used during the event, such as an email, phone number, address, URL, social handle, or payment identifier.

Parameters:

  • type (String)

    Resource family, such as email, phone, name, address, url, instagram, tiktok, yo

  • value (String)

    Resource value used during the event. SafetyKit stores a normalized hash of this



# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1120

Instance Attribute Details

#typeString

Resource family, such as email, phone, name, address, url, instagram, tiktok, youtube, linkedin, or another stable snake_case identifier.

Returns:

  • (String)


1111
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1111

required :type, String

#valueString

Resource value used during the event. SafetyKit stores a normalized hash of this value, not the raw value.

Returns:

  • (String)


1118
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1118

required :value, String