Class: SafetyKit::Models::Beta::EventCreateParams::Body::UserContact

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/safety_kit/models/beta/event_create_params.rb

Defined Under Namespace

Modules: Content, Metadata Classes: ResourcesUsed

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(counterparty_user_id:, event_name:, timestamp:, user_id:, content: nil, metadata: nil, resources_used: nil, type: :user_contact) ⇒ Object

Some parameter documentations has been truncated, see SafetyKit::Models::Beta::EventCreateParams::Body::UserContact for more details.

A user contacts, transacts with, or otherwise interacts with another user. SafetyKit records both users’ perspectives with a shared event_id.

Parameters:



# File 'lib/safety_kit/models/beta/event_create_params.rb', line 105

Instance Attribute Details

#contentArray<SafetyKit::Models::Beta::EventCreateParams::Body::UserContact::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UserContact::Content::EventImageContent>?

User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.



85
86
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 85

optional :content,
-> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::Beta::EventCreateParams::Body::UserContact::Content] }

#counterparty_user_idString

Your stable canonical identifier for the other user in a user-to-user interaction.

Returns:

  • (String)


53
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 53

required :counterparty_user_id, String

#event_nameString

Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.

Returns:

  • (String)


60
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 60

required :event_name, String

#metadataHash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?

Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.

Returns:

  • (Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}, nil)


93
94
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 93

optional :metadata,
-> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::Beta::EventCreateParams::Body::UserContact::Metadata] }

#resources_usedArray<SafetyKit::Models::Beta::EventCreateParams::Body::UserContact::ResourcesUsed>?

Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, or similar identifiers.



102
103
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 102

optional :resources_used,
-> { SafetyKit::Internal::Type::ArrayOf[SafetyKit::Beta::EventCreateParams::Body::UserContact::ResourcesUsed] }

#timestampTime

The time the event occurred in your system, as an ISO 8601 datetime string.

Returns:

  • (Time)


66
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 66

required :timestamp, Time

#typeSymbol, :user_contact

Returns:

  • (Symbol, :user_contact)


71
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 71

required :type, const: :user_contact

#user_idString

Your stable canonical identifier for the user or account.

Returns:

  • (String)


77
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 77

required :user_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/safety_kit/models/beta/event_create_params.rb', line 254