Class: SafetyKit::Models::ClientSessionCreateSessionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::ClientSessionCreateSessionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/safety_kit/models/client_session_create_session_params.rb
Overview
Instance Attribute Summary collapse
-
#customer_session_hash ⇒ String?
Hashed customer browser session value associated with the browser SDK session.
-
#customer_user_id ⇒ String?
Customer user identifier associated with the browser SDK session.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(customer_session_hash: nil, customer_user_id: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(customer_session_hash: nil, customer_user_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/safety_kit/models/client_session_create_session_params.rb', line 22
|
Instance Attribute Details
#customer_session_hash ⇒ String?
Hashed customer browser session value associated with the browser SDK session.
14 |
# File 'lib/safety_kit/models/client_session_create_session_params.rb', line 14 optional :customer_session_hash, String |
#customer_user_id ⇒ String?
Customer user identifier associated with the browser SDK session.
20 |
# File 'lib/safety_kit/models/client_session_create_session_params.rb', line 20 optional :customer_user_id, String |