Class: SafetyKit::Models::ClientSessionCreateSessionParams::Body::UnionMember1

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/safety_kit/models/client_session_create_session_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(customer_session_hash:, customer_user_id: nil) ⇒ Object

Some parameter documentations has been truncated, see SafetyKit::Models::ClientSessionCreateSessionParams::Body::UnionMember1 for more details.

Parameters:

  • customer_session_hash (String)

    Stable opaque customer session hash associated with the browser SDK session.

  • customer_user_id (String) (defaults to: nil)

    Customer user identifier associated with the browser SDK session. Use the same c



# File 'lib/safety_kit/models/client_session_create_session_params.rb', line 76

Instance Attribute Details

#customer_session_hashString

Stable opaque customer session hash associated with the browser SDK session.

Returns:

  • (String)


66
# File 'lib/safety_kit/models/client_session_create_session_params.rb', line 66

required :customer_session_hash, String

#customer_user_idString?

Customer user identifier associated with the browser SDK session. Use the same canonical user ID string that you send as user_id in SafetyKit server-to-server events.

Returns:

  • (String, nil)


74
# File 'lib/safety_kit/models/client_session_create_session_params.rb', line 74

optional :customer_user_id, String