Class: SafetyKit::Models::ContentCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/safety_kit/models/content_create_params.rb,
sig/safety_kit/models/content_create_params.rbs

Overview

See Also:

  • SafetyKit::Resources::Content#create

Defined Under Namespace

Modules: Content, SafetyKitVersion

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::SafetyKit

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content:, user_id:, content_id: nil, metadata: nil, safety_kit_version: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see SafetyKit::Models::ContentCreateParams for more details.

Parameters:



# File 'lib/safety_kit/models/content_create_params.rb', line 43

Instance Attribute Details

#contentArray<SafetyKit::Models::ContentCreateParams::Content::UnionMember0, SafetyKit::Models::ContentCreateParams::Content::UnionMember1>

Content parts to classify together. At most 20 images. Text parts may total 128,000 characters. Text is classified in overlapping windows and a label matches when any window matches.

Parameters:

  • value (::Array[SafetyKit::Models::ContentCreateParams::content])

Returns:



16
17
# File 'lib/safety_kit/models/content_create_params.rb', line 16

required :content,
-> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::ContentCreateParams::Content] }

#content_idString?

Your content identifier.

Parameters:

  • (String)

Returns:

  • (String, nil)


29
# File 'lib/safety_kit/models/content_create_params.rb', line 29

optional :content_id, String

#metadataHash{Symbol=>Object, nil}?

Additional product context for this content. At most 8KB when serialized.

Parameters:

  • (::Hash[Symbol, top?])

Returns:

  • (Hash{Symbol=>Object, nil}, nil)


35
# File 'lib/safety_kit/models/content_create_params.rb', line 35

optional :metadata, SafetyKit::Internal::Type::HashOf[SafetyKit::Internal::Type::Unknown, nil?: true]

#safety_kit_versionSymbol, ...

The API version this operation is defined against.



41
# File 'lib/safety_kit/models/content_create_params.rb', line 41

optional :safety_kit_version, enum: -> { SafetyKit::ContentCreateParams::SafetyKitVersion }

#user_idString

Your stable identifier for the user this content belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


23
# File 'lib/safety_kit/models/content_create_params.rb', line 23

required :user_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/safety_kit/models/content_create_params.rb', line 162

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/safety_kit/models/content_create_params.rbs', line 44

def to_hash: -> {