Class: SafetyKit::Models::ContentCreateParams::Content::UnionMember1::Source
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::ContentCreateParams::Content::UnionMember1::Source
- Defined in:
- lib/safety_kit/models/content_create_params.rb,
sig/safety_kit/models/content_create_params.rbs
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#data ⇒ String
Base64-encoded image bytes, raw or as a data URI.
- #type ⇒ Symbol, SafetyKit::Models::ContentCreateParams::Content::UnionMember1::Source::Type
Instance Method Summary collapse
- #initialize(data:, type:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data:, type:) ⇒ Object
|
|
# File 'lib/safety_kit/models/content_create_params.rb', line 140
|
Instance Attribute Details
#data ⇒ String
Base64-encoded image bytes, raw or as a data URI. At most 5MB.
133 |
# File 'lib/safety_kit/models/content_create_params.rb', line 133 required :data, String |
#type ⇒ Symbol, SafetyKit::Models::ContentCreateParams::Content::UnionMember1::Source::Type
138 |
# File 'lib/safety_kit/models/content_create_params.rb', line 138 required :type, enum: -> { SafetyKit::ContentCreateParams::Content::UnionMember1::Source::Type } |
Instance Method Details
#to_hash ⇒ {
143 |
# File 'sig/safety_kit/models/content_create_params.rbs', line 143
def to_hash: -> {
|