Class: SafetyKit::Models::ContentCreateResponse::ReferenceSetMatch

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/safety_kit/models/content_create_response.rb,
sig/safety_kit/models/content_create_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(set_id:, similarity:) ⇒ ReferenceSetMatch

Reference set match found for the submitted content.

Parameters:

  • set_id (String)

    Identifier of the matched reference set.

  • similarity (Float)

    Similarity between the submitted content and the matched reference set entry.

  • set_id: (String)
  • similarity: (Float)


# File 'lib/safety_kit/models/content_create_response.rb', line 130

Instance Attribute Details

#set_idString

Identifier of the matched reference set.

Parameters:

  • value (String)

Returns:

  • (String)


122
# File 'lib/safety_kit/models/content_create_response.rb', line 122

required :set_id, String

#similarityFloat

Similarity between the submitted content and the matched reference set entry.

Parameters:

  • value (Float)

Returns:

  • (Float)


128
# File 'lib/safety_kit/models/content_create_response.rb', line 128

required :similarity, Float

Instance Method Details

#to_hash{ set_id: String, similarity: Float }

Returns:

  • ({ set_id: String, similarity: Float })


104
# File 'sig/safety_kit/models/content_create_response.rbs', line 104

def to_hash: -> { set_id: String, similarity: Float }