Class: SafetyKit::Models::DataGetSettingsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::DataGetSettingsResponse
- Defined in:
- lib/safety_kit/models/data_get_settings_response.rb,
sig/safety_kit/models/data_get_settings_response.rbs
Overview
Instance Attribute Summary collapse
- #namespace ⇒ String
-
#schema ⇒ Hash{Symbol=>Object, nil}
The stored schema for this namespace, returned exactly as stored.
-
#settings ⇒ Hash{Symbol=>Object, nil}
The stored namespace settings.
-
#version ⇒ Integer
The current configuration version, incremented each time the configuration is updated through the API or by SafetyKit.
Instance Method Summary collapse
-
#initialize(namespace:, schema:, settings:, version:) ⇒ Object
constructor
Some parameter documentations has been truncated, see DataGetSettingsResponse for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(namespace:, schema:, settings:, version:) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::DataGetSettingsResponse for more details.
The namespace's stored configuration and its current version.
|
|
# File 'lib/safety_kit/models/data_get_settings_response.rb', line 32
|
Instance Attribute Details
#namespace ⇒ String
10 |
# File 'lib/safety_kit/models/data_get_settings_response.rb', line 10 required :namespace, String |
#schema ⇒ Hash{Symbol=>Object, nil}
The stored schema for this namespace, returned exactly as stored.
16 |
# File 'lib/safety_kit/models/data_get_settings_response.rb', line 16 required :schema, SafetyKit::Internal::Type::HashOf[SafetyKit::Internal::Type::Unknown, nil?: true] |
#settings ⇒ Hash{Symbol=>Object, nil}
The stored namespace settings. Configure with guidance from SafetyKit.
22 |
# File 'lib/safety_kit/models/data_get_settings_response.rb', line 22 required :settings, SafetyKit::Internal::Type::HashOf[SafetyKit::Internal::Type::Unknown, nil?: true] |
#version ⇒ Integer
The current configuration version, incremented each time the configuration is updated through the API or by SafetyKit. Send it as previous_version when updating to detect intervening changes.
30 |
# File 'lib/safety_kit/models/data_get_settings_response.rb', line 30 required :version, Integer |
Instance Method Details
#to_hash ⇒ {
27 |
# File 'sig/safety_kit/models/data_get_settings_response.rbs', line 27
def to_hash: -> {
|