Class: SafetyKit::Models::DataObject

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/safety_kit/models/data_object.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:) ⇒ Object

Some parameter documentations has been truncated, see SafetyKit::Models::DataObject for more details.

A data object to ingest. It must include an id field. All other fields are flexible and can be any JSON type.

Parameters:

  • id (String)

    Unique identifier for this data object.



# File 'lib/safety_kit/models/data_object.rb', line 14

Instance Attribute Details

#idString

Unique identifier for this data object. This should be a meaningful identifier in the customer’s system, as it is the main way to search for specific items between systems.

Returns:

  • (String)


12
# File 'lib/safety_kit/models/data_object.rb', line 12

required :id, String