Class: SafetyKit::Models::DataUpdateSettingsParams::Schema::DisplayHint
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::DataUpdateSettingsParams::Schema::DisplayHint
- Defined in:
- lib/safety_kit/models/data_update_settings_params.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#name ⇒ String?
Display label to show for this field in the UI.
-
#order ⇒ Float?
Display ordering for this field.
-
#type ⇒ Symbol, ...
The display hint type.
Instance Method Summary collapse
-
#initialize(name: nil, order: nil, type: nil) ⇒ Object
constructor
Display hint for UI rendering of this field.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: nil, order: nil, type: nil) ⇒ Object
Display hint for UI rendering of this field
|
|
# File 'lib/safety_kit/models/data_update_settings_params.rb', line 127
|
Instance Attribute Details
#name ⇒ String?
Display label to show for this field in the UI
113 |
# File 'lib/safety_kit/models/data_update_settings_params.rb', line 113 optional :name, String |
#order ⇒ Float?
Display ordering for this field. Use 0 to hide the field from list views.
119 |
# File 'lib/safety_kit/models/data_update_settings_params.rb', line 119 optional :order, Float |
#type ⇒ Symbol, ...
The display hint type
125 |
# File 'lib/safety_kit/models/data_update_settings_params.rb', line 125 optional :type, enum: -> { SafetyKit::DataUpdateSettingsParams::Schema::DisplayHint::Type } |