Class: SafetyKit::Models::StreamAddFrameParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/safety_kit/models/stream_add_frame_params.rb,
sig/safety_kit/models/stream_add_frame_params.rbs

Overview

See Also:

  • SafetyKit::Resources::Streams#add_frame

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::SafetyKit

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(namespace:, image_data_uri:, stream_id:, timestamp:, frame_id: nil, metadata: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see SafetyKit::Models::StreamAddFrameParams for more details.

Parameters:

  • namespace (String)

    The namespace to ingest stream data into

  • image_data_uri (String)

    A data URI containing a base64-encoded frame image. Only image/jpeg, image/png,

  • stream_id (String)
  • timestamp (Integer)
  • frame_id (String) (defaults to: nil)
  • metadata (Hash{Symbol=>Object, nil}) (defaults to: nil)

    Arbitrary key-value metadata to associate with this frame, at most 8192 bytes wh

  • request_options (SafetyKit::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/safety_kit/models/stream_add_frame_params.rb', line 48

Instance Attribute Details

#frame_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


38
# File 'lib/safety_kit/models/stream_add_frame_params.rb', line 38

optional :frame_id, String

#image_data_uriString

A data URI containing a base64-encoded frame image. Only image/jpeg, image/png, and image/webp are accepted. The decoded bytes must match the declared mime type, decode as a valid image, stay within 5 MB, and stay within 4096x4096 / 16,000,000 total pixels.

Parameters:

  • value (String)

Returns:

  • (String)


23
# File 'lib/safety_kit/models/stream_add_frame_params.rb', line 23

required :image_data_uri, String

#metadataHash{Symbol=>Object, nil}?

Arbitrary key-value metadata to associate with this frame, at most 8192 bytes when serialized. If a violation is detected on this frame, the metadata is echoed back verbatim in the live_video.violation_detected webhook.

Parameters:

  • (::Hash[Symbol, top?])

Returns:

  • (Hash{Symbol=>Object, nil}, nil)


46
# File 'lib/safety_kit/models/stream_add_frame_params.rb', line 46

optional :metadata, SafetyKit::Internal::Type::HashOf[SafetyKit::Internal::Type::Unknown, nil?: true]

#namespaceString

The namespace to ingest stream data into

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/safety_kit/models/stream_add_frame_params.rb', line 14

required :namespace, String

#stream_idString

Parameters:

  • value (String)

Returns:

  • (String)


28
# File 'lib/safety_kit/models/stream_add_frame_params.rb', line 28

required :stream_id, String

#timestampInteger

Parameters:

  • value (Integer)

Returns:

  • (Integer)


33
# File 'lib/safety_kit/models/stream_add_frame_params.rb', line 33

required :timestamp, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/safety_kit/models/stream_add_frame_params.rbs', line 44

def to_hash: -> {