Class: SafetyKit::Client
- Inherits:
-
Internal::Transport::BaseClient
- Object
- Internal::Transport::BaseClient
- SafetyKit::Client
- Defined in:
- lib/safety_kit/client.rb
Constant Summary collapse
- DEFAULT_MAX_RETRIES =
Default max number of retries to attempt after a failed retryable request.
2- DEFAULT_TIMEOUT_IN_SECONDS =
Default per-request timeout.
60.0- DEFAULT_INITIAL_RETRY_DELAY =
Default initial retry delay in seconds. Overall delay is calculated using exponential backoff + jitter.
0.5- DEFAULT_MAX_RETRY_DELAY =
Default max retry delay in seconds.
8.0
Constants inherited from Internal::Transport::BaseClient
Internal::Transport::BaseClient::MAX_REDIRECTS, Internal::Transport::BaseClient::PLATFORM_HEADERS
Instance Attribute Summary collapse
-
#agent_decisions ⇒ SafetyKit::Resources::AgentDecisions
readonly
Send human reviewer final verdicts to SafetyKit.
-
#api_key ⇒ String
readonly
PropelAuth JWT token.
- #beta ⇒ SafetyKit::Resources::Beta readonly
-
#client_sessions ⇒ SafetyKit::Resources::ClientSessions
readonly
Create browser-safe webapp SDK session tokens from authenticated server-side code.
-
#data ⇒ SafetyKit::Resources::Data
readonly
Ingest data for fraud detection and risk analysis.
-
#streams ⇒ SafetyKit::Resources::Streams
readonly
Ingest and monitor livestream content.
Attributes inherited from Internal::Transport::BaseClient
#base_url, #headers, #idempotency_header, #initial_retry_delay, #max_retries, #max_retry_delay, #requester, #timeout
Instance Method Summary collapse
-
#initialize(api_key: ENV["SAFETYKIT_API_KEY"], base_url: ENV["SAFETYKIT_BASE_URL"], max_retries: self.class::DEFAULT_MAX_RETRIES, timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY) ⇒ Client
constructor
Creates and returns a new client for interacting with the API.
Methods inherited from Internal::Transport::BaseClient
follow_redirect, #inspect, reap_connection!, #request, #send_request, should_retry?, validate!
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(api_key: ENV["SAFETYKIT_API_KEY"], base_url: ENV["SAFETYKIT_BASE_URL"], max_retries: self.class::DEFAULT_MAX_RETRIES, timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY) ⇒ Client
Creates and returns a new client for interacting with the API.
‘“api.example.com/v2/”`. Defaults to `ENV`
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/safety_kit/client.rb', line 66 def initialize( api_key: ENV["SAFETYKIT_API_KEY"], base_url: ENV["SAFETYKIT_BASE_URL"], max_retries: self.class::DEFAULT_MAX_RETRIES, timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY ) base_url ||= "https://api.safetykit.com" if api_key.nil? raise ArgumentError.new("api_key is required, and can be set via environ: \"SAFETYKIT_API_KEY\"") end headers = {} custom_headers_env = ENV["SAFETYKIT_CUSTOM_HEADERS"] unless custom_headers_env.nil? parsed = {} custom_headers_env.split("\n").each do |line| colon = line.index(":") unless colon.nil? parsed[line[0...colon].strip] = line[(colon + 1)..].strip end end headers = parsed.merge(headers) end @api_key = api_key.to_s super( base_url: base_url, timeout: timeout, max_retries: max_retries, initial_retry_delay: initial_retry_delay, max_retry_delay: max_retry_delay, headers: headers ) @data = SafetyKit::Resources::Data.new(client: self) @streams = SafetyKit::Resources::Streams.new(client: self) @agent_decisions = SafetyKit::Resources::AgentDecisions.new(client: self) @client_sessions = SafetyKit::Resources::ClientSessions.new(client: self) @beta = SafetyKit::Resources::Beta.new(client: self) end |
Instance Attribute Details
#agent_decisions ⇒ SafetyKit::Resources::AgentDecisions (readonly)
Send human reviewer final verdicts to SafetyKit. This feedback improves the accuracy of SafetyKit’s automated decisions over time.
33 34 35 |
# File 'lib/safety_kit/client.rb', line 33 def agent_decisions @agent_decisions end |
#api_key ⇒ String (readonly)
PropelAuth JWT token
20 21 22 |
# File 'lib/safety_kit/client.rb', line 20 def api_key @api_key end |
#beta ⇒ SafetyKit::Resources::Beta (readonly)
41 42 43 |
# File 'lib/safety_kit/client.rb', line 41 def beta @beta end |
#client_sessions ⇒ SafetyKit::Resources::ClientSessions (readonly)
Create browser-safe webapp SDK session tokens from authenticated server-side code.
38 39 40 |
# File 'lib/safety_kit/client.rb', line 38 def client_sessions @client_sessions end |
#data ⇒ SafetyKit::Resources::Data (readonly)
Ingest data for fraud detection and risk analysis.
24 25 26 |
# File 'lib/safety_kit/client.rb', line 24 def data @data end |
#streams ⇒ SafetyKit::Resources::Streams (readonly)
Ingest and monitor livestream content.
28 29 30 |
# File 'lib/safety_kit/client.rb', line 28 def streams @streams end |