Class: SafetyKit::Models::AccessTokenCreateAccessTokenParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::AccessTokenCreateAccessTokenParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/safety_kit/models/access_token_create_access_token_params.rb,
sig/safety_kit/models/access_token_create_access_token_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::SafetyKit
Instance Attribute Summary collapse
-
#customer_session_id ⇒ String?
Optional opaque session identifier to associate with the access token.
-
#expires_in ⇒ Integer?
Lifetime of the access token in seconds.
-
#user_id ⇒ String?
Optional user identifier to associate with the access token for attribution.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(customer_session_id: nil, expires_in: nil, user_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AccessTokenCreateAccessTokenParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(customer_session_id: nil, expires_in: nil, user_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::AccessTokenCreateAccessTokenParams for more details.
|
|
# File 'lib/safety_kit/models/access_token_create_access_token_params.rb', line 30
|
Instance Attribute Details
#customer_session_id ⇒ String?
Optional opaque session identifier to associate with the access token.
14 |
# File 'lib/safety_kit/models/access_token_create_access_token_params.rb', line 14 optional :customer_session_id, String |
#expires_in ⇒ Integer?
Lifetime of the access token in seconds. Defaults to 3600 (1 hour). Minimum 300 (5 minutes), maximum 43200 (12 hours).
21 |
# File 'lib/safety_kit/models/access_token_create_access_token_params.rb', line 21 optional :expires_in, Integer |
#user_id ⇒ String?
Optional user identifier to associate with the access token for attribution. Use the same canonical user ID string that you send in other SafetyKit API calls.
28 |
# File 'lib/safety_kit/models/access_token_create_access_token_params.rb', line 28 optional :user_id, String |
Instance Method Details
#to_hash ⇒ {
30 |
# File 'sig/safety_kit/models/access_token_create_access_token_params.rbs', line 30
def to_hash: -> {
|