Class: SafetyKit::Models::AgentDecisionCreateAgentDecisionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::AgentDecisionCreateAgentDecisionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/safety_kit/models/agent_decision_create_agent_decision_params.rb
Overview
Instance Attribute Summary collapse
-
#action ⇒ String?
Optional correct enforcement action for this content, such as ‘reduce_visibility’ or ‘unpublish’.
-
#agent_type ⇒ String?
Optional type of review that produced this decision, such as ‘appeal’, ‘bpo_review’, or ‘policy_expert’.
-
#comment ⇒ String?
Additional context or details from the human reviewer.
-
#content_type ⇒ String
The SafetyKit data namespace or content type for the content being reviewed.
-
#decision ⇒ String
The human reviewer’s verdict for the policy category.
-
#policy_id ⇒ String
The SafetyKit policy category ID that was evaluated, as configured for your account.
-
#reference_id ⇒ String
Stable identifier for the content object in your system.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(content_type:, decision:, policy_id:, reference_id:, action: nil, agent_type: nil, comment: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AgentDecisionCreateAgentDecisionParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content_type:, decision:, policy_id:, reference_id:, action: nil, agent_type: nil, comment: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::AgentDecisionCreateAgentDecisionParams for more details.
|
|
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 55
|
Instance Attribute Details
#action ⇒ String?
Optional correct enforcement action for this content, such as ‘reduce_visibility’ or ‘unpublish’
40 |
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 40 optional :action, String |
#agent_type ⇒ String?
Optional type of review that produced this decision, such as ‘appeal’, ‘bpo_review’, or ‘policy_expert’
47 |
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 47 optional :agent_type, String |
#comment ⇒ String?
Additional context or details from the human reviewer
53 |
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 53 optional :comment, String, nil?: true |
#content_type ⇒ String
The SafetyKit data namespace or content type for the content being reviewed
14 |
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 14 required :content_type, String |
#decision ⇒ String
The human reviewer’s verdict for the policy category.
20 |
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 20 required :decision, String |
#policy_id ⇒ String
The SafetyKit policy category ID that was evaluated, as configured for your account
27 |
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 27 required :policy_id, String |
#reference_id ⇒ String
Stable identifier for the content object in your system
33 |
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 33 required :reference_id, String |