Class: SafetyKit::Models::AgentDecisionCreateAgentDecisionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::AgentDecisionCreateAgentDecisionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/safety_kit/models/agent_decision_create_agent_decision_params.rb
Overview
Instance Attribute Summary collapse
-
#action ⇒ String?
The correct enforcement action for this content (e.g. ‘reduce_visibility’, ‘unpublish’).
-
#comment ⇒ String?
Additional context or details from the human reviewer.
-
#content_type ⇒ String
The dataapi namespace of the content being reviewed.
-
#decision ⇒ String
The human reviewer’s verdict on whether the content violates the specified policy (‘match’/‘no_match’).
-
#policy_id ⇒ String
The SafetyKit policy category ID that was evaluated, as configured for your account.
-
#reference_id ⇒ String
The external id for the content being reviewed.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(content_type:, decision:, policy_id:, reference_id:, action: nil, comment: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AgentDecisionCreateAgentDecisionParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content_type:, decision:, policy_id:, reference_id:, action: nil, comment: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::AgentDecisionCreateAgentDecisionParams for more details.
|
|
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 49
|
Instance Attribute Details
#action ⇒ String?
The correct enforcement action for this content (e.g. ‘reduce_visibility’, ‘unpublish’)
41 |
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 41 optional :action, String |
#comment ⇒ String?
Additional context or details from the human reviewer
47 |
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 47 optional :comment, String, nil?: true |
#content_type ⇒ String
The dataapi namespace of the content being reviewed
14 |
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 14 required :content_type, String |
#decision ⇒ String
The human reviewer’s verdict on whether the content violates the specified policy (‘match’/‘no_match’).
21 |
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 21 required :decision, String |
#policy_id ⇒ String
The SafetyKit policy category ID that was evaluated, as configured for your account
28 |
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 28 required :policy_id, String |
#reference_id ⇒ String
The external id for the content being reviewed
34 |
# File 'lib/safety_kit/models/agent_decision_create_agent_decision_params.rb', line 34 required :reference_id, String |