Class: SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest
- Defined in:
- lib/safety_kit/models/async_create_async_params.rb
Defined Under Namespace
Modules: Content, Metadata, ResourcesUsed, Type Classes: ClientInfo
Instance Attribute Summary collapse
-
#client_info ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
-
#content ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventImageContent>?
User-authored or user-uploaded content parts.
-
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
-
#event_name ⇒ String
Stable, low-cardinality product action name.
-
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent.
-
#labels ⇒ Array<String>
One or more label categories supplied with the report or moderation decision.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging.
-
#resources_used ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::EntityIDResource, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event.
-
#target_content_id ⇒ String?
Your stable identifier for the content being reported.
-
#target_user_id ⇒ String?
Your stable canonical identifier for the user being reported.
-
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
- #type ⇒ Symbol, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Type
-
#user_id ⇒ String
Your stable canonical identifier for the user or account.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventImageContent)
Instance Method Summary collapse
-
#initialize(ip: nil) ⇒ Object
constructor
Client context observed by your backend for the user action that triggered the event.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ip: nil) ⇒ Object
Client context observed by your backend for the user action that triggered the event.
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2204
|
Instance Attribute Details
#client_info ⇒ SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
2150 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2150 optional :client_info, -> { SafetyKit::AsyncCreateAsyncParams::Body::UserReportEventRequest::ClientInfo } |
#content ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventImageContent>?
User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.
2158 2159 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2158 optional :content, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content] } |
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
2166 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2166 optional :content_id, String |
#event_name ⇒ String
Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.
2120 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2120 required :event_name, String |
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent. Reuse the same key only for retries of the same logical event.
2173 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2173 optional :idempotency_key, String |
#labels ⇒ Array<String>
One or more label categories supplied with the report or moderation decision.
2126 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2126 required :labels, SafetyKit::Internal::Type::ArrayOf[String] |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.
2180 2181 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2180 optional :metadata, -> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UserReportEventRequest::Metadata] } |
#resources_used ⇒ Array<SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::EntityIDResource, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed::UnionMember1>?
Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, caller-defined ids, or similar identifiers.
2189 2190 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2189 optional :resources_used, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::AsyncCreateAsyncParams::Body::UserReportEventRequest::ResourcesUsed] } |
#target_content_id ⇒ String?
Your stable identifier for the content being reported.
2196 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2196 optional :target_content_id, String |
#target_user_id ⇒ String?
Your stable canonical identifier for the user being reported.
2202 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2202 optional :target_user_id, String |
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
2132 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2132 required :timestamp, Time |
#type ⇒ Symbol, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Type
2137 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2137 required :type, enum: -> { SafetyKit::AsyncCreateAsyncParams::Body::UserReportEventRequest::Type } |
#user_id ⇒ String
Your stable canonical identifier for the user or account.
2143 |
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2143 required :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2246
|
.variants ⇒ Array(SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventTextContent, SafetyKit::Models::AsyncCreateAsyncParams::Body::UserReportEventRequest::Content::EventImageContent)
|
|
# File 'lib/safety_kit/models/async_create_async_params.rb', line 2395
|