Class: SafetyKit::Models::Beta::EventCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::Beta::EventCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/safety_kit/models/beta/event_create_params.rb
Overview
Defined Under Namespace
Modules: Body
Instance Attribute Summary collapse
-
#body ⇒ SafetyKit::Models::Beta::EventCreateParams::Body::UserContactEventRequest, ...
Backend event or ordered batch of events to send to SafetyKit.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(body:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see EventCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(body:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::Beta::EventCreateParams for more details.
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 19
|
Instance Attribute Details
#body ⇒ SafetyKit::Models::Beta::EventCreateParams::Body::UserContactEventRequest, ...
Backend event or ordered batch of events to send to SafetyKit. Send events from your server after an action has happened in your product. Do not send these events directly from a browser or mobile client.
17 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 17 required :body, union: -> { SafetyKit::Beta::EventCreateParams::Body } |