Module: SafetyKit::Models::Beta::EventCreateParams::Body
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/safety_kit/models/beta/event_create_params.rb
Overview
Backend event to send to SafetyKit. Send events from your server after an action has happened in your product. Do not send these events directly from a browser or mobile client.
Defined Under Namespace
Classes: ContentUploaded, CreateAccount, UpdateAccount, UserContact
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(type:, value:) ⇒ Object
Some parameter documentations has been truncated, see CreateAccount::ResourcesUsed for more details.
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(SafetyKit::Models::Beta::EventCreateParams::Body::UserContact, SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded, SafetyKit::Models::Beta::EventCreateParams::Body::CreateAccount, SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount)
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1134
|
Instance Method Details
#initialize(type:, value:) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::Beta::EventCreateParams::Body::CreateAccount::ResourcesUsed for more details.
Real-world or account resource used during the event, such as an email, phone number, address, URL, social handle, or payment identifier.
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 312
|