Class: SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded
- Defined in:
- lib/safety_kit/models/beta/event_create_params.rb
Defined Under Namespace
Modules: Content, Metadata Classes: ResourcesUsed
Instance Attribute Summary collapse
-
#content ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded::Content::EventImageContent>
User-authored or user-uploaded content parts.
-
#event_name ⇒ String
Stable, low-cardinality product action name.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging.
-
#resources_used ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded::ResourcesUsed>?
Reusable resources observed during the event.
-
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
- #type ⇒ Symbol, :content_uploaded
-
#user_id ⇒ String
Your stable canonical identifier for the user or account.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded::Content::EventImageContent)
Instance Method Summary collapse
-
#initialize(content:, event_name:, timestamp:, user_id:, metadata: nil, resources_used: nil, type: :content_uploaded) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContentUploaded for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content:, event_name:, timestamp:, user_id:, metadata: nil, resources_used: nil, type: :content_uploaded) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded for more details.
A user posts, uploads, publishes, edits, or replaces content.
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 377
|
Instance Attribute Details
#content ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded::Content::EventImageContent>
User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.
333 334 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 333 required :content, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::Beta::EventCreateParams::Body::ContentUploaded::Content] } |
#event_name ⇒ String
Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.
341 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 341 required :event_name, String |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.
365 366 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 365 optional :metadata, -> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::Beta::EventCreateParams::Body::ContentUploaded::Metadata] } |
#resources_used ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded::ResourcesUsed>?
Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, or similar identifiers.
374 375 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 374 optional :resources_used, -> { SafetyKit::Internal::Type::ArrayOf[SafetyKit::Beta::EventCreateParams::Body::ContentUploaded::ResourcesUsed] } |
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
347 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 347 required :timestamp, Time |
#type ⇒ Symbol, :content_uploaded
352 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 352 required :type, const: :content_uploaded |
#user_id ⇒ String
Your stable canonical identifier for the user or account.
358 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 358 required :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 523
|
.variants ⇒ Array(SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::ContentUploaded::Content::EventImageContent)
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 528
|