Module: SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4

Extended by:
Internal::Type::Union
Defined in:
lib/safety_kit/models/beta/event_create_params.rb

Overview

A user contacts, transacts with, or otherwise interacts with another user.

Defined Under Namespace

Classes: ContentUploaded, CreateAccount, UpdateAccount, UserContact

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(type:, value:) ⇒ Object

Some parameter documentations has been truncated, see SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember4::CreateAccount::ResourcesUsed for more details.

Real-world or account resource used during the event, such as an email, phone number, address, URL, social handle, or payment identifier.

Parameters:

  • type (String)

    Resource family, such as email, phone, name, address, url, instagram, tiktok, yo

  • value (String)

    Resource value used during the event. SafetyKit stores a normalized hash of this



# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1455