Class: SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision
- Defined in:
- lib/safety_kit/models/beta/event_create_params.rb
Defined Under Namespace
Modules: Content, Metadata, SourceType Classes: Label, ResourcesUsed
Instance Attribute Summary collapse
-
#content ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::Content::EventImageContent>?
User-authored or user-uploaded content parts.
-
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
-
#event_name ⇒ String
Stable, low-cardinality product action name.
-
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent.
-
#labels ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::Label>
One or more label categories supplied with the report.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging.
-
#resources_used ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::ResourcesUsed>?
Reusable resources observed during the event.
-
#source_id ⇒ String
Stable identifier within source_type.
-
#source_type ⇒ Symbol, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::SourceType
Coarse attribution category for the moderation decision source.
-
#target_content_id ⇒ String?
Your stable identifier for the content being reported.
-
#target_user_id ⇒ String?
Your stable canonical identifier for the user being reported.
-
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
- #type ⇒ Symbol, :moderation_decision
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::Content::EventImageContent)
Instance Method Summary collapse
-
#initialize(label:) ⇒ Object
constructor
Label category supplied with a user report.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(label:) ⇒ Object
Label category supplied with a user report.
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3613
|
Instance Attribute Details
#content ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::Content::EventImageContent>?
User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.
3525 3526 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3525 optional :content, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::Content] } |
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
3533 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3533 optional :content_id, String |
#event_name ⇒ String
Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.
3479 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3479 required :event_name, String |
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent. Reuse the same key only for retries of the same logical event.
3540 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3540 optional :idempotency_key, String |
#labels ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::Label>
One or more label categories supplied with the report.
3485 3486 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3485 required :labels, -> { SafetyKit::Internal::Type::ArrayOf[SafetyKit::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::Label] } |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.
3547 3548 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3547 optional :metadata, -> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::Metadata] } |
#resources_used ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::ResourcesUsed>?
Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, or similar identifiers.
3556 3557 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3556 optional :resources_used, -> { SafetyKit::Internal::Type::ArrayOf[SafetyKit::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::ResourcesUsed] } |
#source_id ⇒ String
Stable identifier within source_type. Examples: reviewer_123 for human_moderator, labeling_job_456 for expert_labeler, automated_review_v2026_06_04 for automation, or external_review_batch_789 for vendor. Use stable opaque IDs rather than vendor names.
3495 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3495 required :source_id, String |
#source_type ⇒ Symbol, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::SourceType
Coarse attribution category for the moderation decision source. Supported values: human_moderator (a human reviewer in your moderation workflow), expert_labeler (a dedicated labeling or quality review workflow), automation (an automated model, rules engine, or enforcement workflow), or vendor (an external review or moderation provider).
3505 3506 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3505 required :source_type, enum: -> { SafetyKit::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::SourceType } |
#target_content_id ⇒ String?
Your stable identifier for the content being reported.
3563 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3563 optional :target_content_id, String |
#target_user_id ⇒ String?
Your stable canonical identifier for the user being reported.
3569 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3569 optional :target_user_id, String |
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
3512 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3512 required :timestamp, Time |
#type ⇒ Symbol, :moderation_decision
3517 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3517 required :type, const: :moderation_decision |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3634
|
.variants ⇒ Array(SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember6::ModerationDecision::Content::EventImageContent)
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3768
|