Class: SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product
- Defined in:
- lib/safety_kit/models/beta/event_create_params.rb
Overview
Defined Under Namespace
Classes: DiscountedPrice, Price
Instance Attribute Summary collapse
-
#discounted_price ⇒ SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product::DiscountedPrice?
Discounted price of the product, when a discount applies.
-
#price ⇒ SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product::Price
Current listed price of the product.
-
#shipping_info ⇒ Hash{Symbol=>Object, nil}?
Shipping details for the product, such as cost, regions, and carrier.
Instance Method Summary collapse
-
#initialize(amount:, currency:) ⇒ Object
constructor
Current listed price of the product.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, currency:) ⇒ Object
Current listed price of the product.
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3212
|
Instance Attribute Details
#discounted_price ⇒ SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product::DiscountedPrice?
Discounted price of the product, when a discount applies.
3202 3203 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3202 optional :discounted_price, -> { SafetyKit::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product::DiscountedPrice } |
#price ⇒ SafetyKit::Models::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product::Price
Current listed price of the product.
3195 3196 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3195 required :price, -> { SafetyKit::Beta::EventCreateParams::Body::UnionMember7::ProductChanged::Product::Price } |
#shipping_info ⇒ Hash{Symbol=>Object, nil}?
Shipping details for the product, such as cost, regions, and carrier.
3209 3210 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 3209 optional :shipping_info, SafetyKit::Internal::Type::HashOf[SafetyKit::Internal::Type::Unknown, nil?: true] |