Class: SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::ResourcesUsed
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::ResourcesUsed
- Defined in:
- lib/safety_kit/models/beta/event_create_params.rb
Instance Attribute Summary collapse
-
#type ⇒ String
Resource family, such as email, phone, name, address, url, instagram, tiktok, youtube, linkedin, or another stable snake_case identifier.
-
#value ⇒ String
Resource value used during the event.
Instance Method Summary collapse
-
#initialize(type:, value:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ResourcesUsed for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:, value:) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::Beta::EventCreateParams::Body::UpdateAccount::ResourcesUsed for more details.
Real-world or account resource used during the event, such as an email, phone number, address, URL, social handle, or payment identifier.
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1120
|
Instance Attribute Details
#type ⇒ String
Resource family, such as email, phone, name, address, url, instagram, tiktok, youtube, linkedin, or another stable snake_case identifier.
1111 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1111 required :type, String |
#value ⇒ String
Resource value used during the event. SafetyKit stores a normalized hash of this value, not the raw value.
1118 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1118 required :value, String |