Class: SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest
- Defined in:
- lib/safety_kit/models/beta/event_create_params.rb
Defined Under Namespace
Modules: Content, Metadata, Type Classes: ClientInfo, ResourcesUsed
Instance Attribute Summary collapse
-
#client_info ⇒ SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
-
#content ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::Content::EventImageContent>?
User-authored or user-uploaded content parts.
-
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
-
#event_name ⇒ String
Stable, low-cardinality product action name.
-
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent.
-
#labels ⇒ Array<String>
One or more label categories supplied with the report or moderation decision.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging.
-
#resources_used ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::ResourcesUsed>?
Reusable resources observed during the event.
-
#target_content_id ⇒ String?
Your stable identifier for the content being reported.
-
#target_user_id ⇒ String?
Your stable canonical identifier for the user being reported.
-
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
- #type ⇒ Symbol, SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::Type
-
#user_id ⇒ String
Your stable canonical identifier for the user or account.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::Content::EventImageContent)
Instance Method Summary collapse
-
#initialize(ip: nil) ⇒ Object
constructor
Client context observed by your backend for the user action that triggered the event.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ip: nil) ⇒ Object
Client context observed by your backend for the user action that triggered the event.
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1886
|
Instance Attribute Details
#client_info ⇒ SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::ClientInfo?
Client context observed by your backend for the user action that triggered the event.
1832 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1832 optional :client_info, -> { SafetyKit::Beta::EventCreateParams::Body::UserReportEventRequest::ClientInfo } |
#content ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::Content::EventImageContent>?
User-authored or user-uploaded content parts. Use this for message bodies, bios, listing text, image URLs, and similar content SafetyKit should compare or analyze.
1840 1841 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1840 optional :content, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::Beta::EventCreateParams::Body::UserReportEventRequest::Content] } |
#content_id ⇒ String?
Your stable identifier for the content involved in this event, such as a message, listing, page, post, profile, or uploaded media item.
1848 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1848 optional :content_id, String |
#event_name ⇒ String
Stable, low-cardinality product action name. Use snake_case and put dynamic values in typed fields, content, resources_used, or metadata.
1802 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1802 required :event_name, String |
#idempotency_key ⇒ String?
Optional caller-provided key used to make retries of this individual event idempotent. Reuse the same key only for retries of the same logical event.
1855 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1855 optional :idempotency_key, String |
#labels ⇒ Array<String>
One or more label categories supplied with the report or moderation decision.
1808 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1808 required :labels, SafetyKit::Internal::Type::ArrayOf[String] |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean, Array<String, Float, Boolean>}?
Non-PII product context for filtering, segmentation, and debugging. Values may be strings, numbers, booleans, or arrays of those scalar values.
1862 1863 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1862 optional :metadata, -> { SafetyKit::Internal::Type::HashOf[union: SafetyKit::Beta::EventCreateParams::Body::UserReportEventRequest::Metadata] } |
#resources_used ⇒ Array<SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::ResourcesUsed>?
Reusable resources observed during the event. Use this for emails, phone numbers, names, addresses, social handles, URLs, payment identifiers, or similar identifiers.
1871 1872 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1871 optional :resources_used, -> { SafetyKit::Internal::Type::ArrayOf[SafetyKit::Beta::EventCreateParams::Body::UserReportEventRequest::ResourcesUsed] } |
#target_content_id ⇒ String?
Your stable identifier for the content being reported.
1878 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1878 optional :target_content_id, String |
#target_user_id ⇒ String?
Your stable canonical identifier for the user being reported.
1884 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1884 optional :target_user_id, String |
#timestamp ⇒ Time
The time the event occurred in your system, as an ISO 8601 datetime string.
1814 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1814 required :timestamp, Time |
#type ⇒ Symbol, SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::Type
1819 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1819 required :type, enum: -> { SafetyKit::Beta::EventCreateParams::Body::UserReportEventRequest::Type } |
#user_id ⇒ String
Your stable canonical identifier for the user or account.
1825 |
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1825 required :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 1928
|
.variants ⇒ Array(SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::Content::EventTextContent, SafetyKit::Models::Beta::EventCreateParams::Body::UserReportEventRequest::Content::EventImageContent)
|
|
# File 'lib/safety_kit/models/beta/event_create_params.rb', line 2077
|