Class: SafetyKit::Models::ContentCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::ContentCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/safety_kit/models/content_create_params.rb,
sig/safety_kit/models/content_create_params.rbs
Overview
Defined Under Namespace
Modules: Content, SafetyKitVersion
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::SafetyKit
Instance Attribute Summary collapse
-
#content ⇒ Array<SafetyKit::Models::ContentCreateParams::Content::UnionMember0, SafetyKit::Models::ContentCreateParams::Content::UnionMember1>
Content parts to classify together.
-
#content_id ⇒ String?
Your content identifier.
-
#metadata ⇒ Hash{Symbol=>Object, nil}?
Additional product context for this content.
-
#safety_kit_version ⇒ Symbol, ...
The API version this operation is defined against.
-
#user_id ⇒ String
Your stable identifier for the user this content belongs to.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SafetyKit::Models::ContentCreateParams::Content::UnionMember0, SafetyKit::Models::ContentCreateParams::Content::UnionMember1)
Instance Method Summary collapse
-
#initialize(content:, user_id:, content_id: nil, metadata: nil, safety_kit_version: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContentCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content:, user_id:, content_id: nil, metadata: nil, safety_kit_version: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::ContentCreateParams for more details.
|
|
# File 'lib/safety_kit/models/content_create_params.rb', line 43
|
Instance Attribute Details
#content ⇒ Array<SafetyKit::Models::ContentCreateParams::Content::UnionMember0, SafetyKit::Models::ContentCreateParams::Content::UnionMember1>
Content parts to classify together. At most 20 images. Text parts may total 128,000 characters. Text is classified in overlapping windows and a label matches when any window matches.
16 17 |
# File 'lib/safety_kit/models/content_create_params.rb', line 16 required :content, -> { SafetyKit::Internal::Type::ArrayOf[union: SafetyKit::ContentCreateParams::Content] } |
#content_id ⇒ String?
Your content identifier.
29 |
# File 'lib/safety_kit/models/content_create_params.rb', line 29 optional :content_id, String |
#metadata ⇒ Hash{Symbol=>Object, nil}?
Additional product context for this content. At most 8KB when serialized.
35 |
# File 'lib/safety_kit/models/content_create_params.rb', line 35 optional :metadata, SafetyKit::Internal::Type::HashOf[SafetyKit::Internal::Type::Unknown, nil?: true] |
#safety_kit_version ⇒ Symbol, ...
The API version this operation is defined against.
41 |
# File 'lib/safety_kit/models/content_create_params.rb', line 41 optional :safety_kit_version, enum: -> { SafetyKit::ContentCreateParams::SafetyKitVersion } |
#user_id ⇒ String
Your stable identifier for the user this content belongs to.
23 |
# File 'lib/safety_kit/models/content_create_params.rb', line 23 required :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/safety_kit/models/content_create_params.rb', line 162
|
.variants ⇒ Array(SafetyKit::Models::ContentCreateParams::Content::UnionMember0, SafetyKit::Models::ContentCreateParams::Content::UnionMember1)
|
|
# File 'lib/safety_kit/models/content_create_params.rb', line 167
|
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/safety_kit/models/content_create_params.rbs', line 44
def to_hash: -> {
|