Class: SafetyKit::Models::ContentCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/safety_kit/models/content_create_params.rb,
sig/safety_kit/models/content_create_params.rbs

Overview

See Also:

  • SafetyKit::Resources::Content#create

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::SafetyKit

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(user_id:, content_id: nil, images: nil, metadata: nil, text: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see SafetyKit::Models::ContentCreateParams for more details.

Parameters:

  • user_id (String)

    Your stable identifier for the user this content belongs to.

  • content_id (String) (defaults to: nil)

    Your content identifier.

  • images (Array<String>) (defaults to: nil)

    Images to classify, each as base64-encoded image bytes, raw or as a data URI. At

  • metadata (Hash{Symbol=>Object, nil}) (defaults to: nil)

    Additional product context for this content. At most 8KB when serialized.

  • text (String) (defaults to: nil)

    User-authored text to classify.

  • request_options (SafetyKit::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/safety_kit/models/content_create_params.rb', line 41

Instance Attribute Details

#content_idString?

Your content identifier.

Parameters:

  • (String)

Returns:

  • (String, nil)


20
# File 'lib/safety_kit/models/content_create_params.rb', line 20

optional :content_id, String

#imagesArray<String>?

Images to classify, each as base64-encoded image bytes, raw or as a data URI. At most 5MB each.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


27
# File 'lib/safety_kit/models/content_create_params.rb', line 27

optional :images, SafetyKit::Internal::Type::ArrayOf[String]

#metadataHash{Symbol=>Object, nil}?

Additional product context for this content. At most 8KB when serialized.

Parameters:

  • (::Hash[Symbol, top?])

Returns:

  • (Hash{Symbol=>Object, nil}, nil)


33
# File 'lib/safety_kit/models/content_create_params.rb', line 33

optional :metadata, SafetyKit::Internal::Type::HashOf[SafetyKit::Internal::Type::Unknown, nil?: true]

#textString?

User-authored text to classify.

Parameters:

  • (String)

Returns:

  • (String, nil)


39
# File 'lib/safety_kit/models/content_create_params.rb', line 39

optional :text, String

#user_idString

Your stable identifier for the user this content belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/safety_kit/models/content_create_params.rb', line 14

required :user_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/safety_kit/models/content_create_params.rbs', line 44

def to_hash: -> {