Class: SafetyKit::Models::ContentCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::ContentCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/safety_kit/models/content_create_params.rb,
sig/safety_kit/models/content_create_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::SafetyKit
Instance Attribute Summary collapse
-
#content_id ⇒ String?
Your content identifier.
-
#images ⇒ Array<String>?
Images to classify, each as base64-encoded image bytes, raw or as a data URI.
-
#metadata ⇒ Hash{Symbol=>Object, nil}?
Additional product context for this content.
-
#text ⇒ String?
User-authored text to classify.
-
#user_id ⇒ String
Your stable identifier for the user this content belongs to.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(user_id:, content_id: nil, images: nil, metadata: nil, text: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContentCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(user_id:, content_id: nil, images: nil, metadata: nil, text: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::ContentCreateParams for more details.
|
|
# File 'lib/safety_kit/models/content_create_params.rb', line 41
|
Instance Attribute Details
#content_id ⇒ String?
Your content identifier.
20 |
# File 'lib/safety_kit/models/content_create_params.rb', line 20 optional :content_id, String |
#images ⇒ Array<String>?
Images to classify, each as base64-encoded image bytes, raw or as a data URI. At most 5MB each.
27 |
# File 'lib/safety_kit/models/content_create_params.rb', line 27 optional :images, SafetyKit::Internal::Type::ArrayOf[String] |
#metadata ⇒ Hash{Symbol=>Object, nil}?
Additional product context for this content. At most 8KB when serialized.
33 |
# File 'lib/safety_kit/models/content_create_params.rb', line 33 optional :metadata, SafetyKit::Internal::Type::HashOf[SafetyKit::Internal::Type::Unknown, nil?: true] |
#text ⇒ String?
User-authored text to classify.
39 |
# File 'lib/safety_kit/models/content_create_params.rb', line 39 optional :text, String |
#user_id ⇒ String
Your stable identifier for the user this content belongs to.
14 |
# File 'lib/safety_kit/models/content_create_params.rb', line 14 required :user_id, String |
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/safety_kit/models/content_create_params.rbs', line 44
def to_hash: -> {
|