Class: SafetyKit::Models::ContentCreateResponse::ReferenceSetMatch
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::ContentCreateResponse::ReferenceSetMatch
- Defined in:
- lib/safety_kit/models/content_create_response.rb,
sig/safety_kit/models/content_create_response.rbs
Instance Attribute Summary collapse
-
#set_id ⇒ String
Identifier of the matched reference set.
-
#similarity ⇒ Float
Similarity between the submitted content and the matched reference set entry.
Instance Method Summary collapse
-
#initialize ⇒ ReferenceSetMatch
constructor
A new instance of ReferenceSetMatch.
- #to_hash ⇒ { set_id: String, similarity: Float }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ ReferenceSetMatch
Returns a new instance of ReferenceSetMatch.
80 |
# File 'sig/safety_kit/models/content_create_response.rbs', line 80
def initialize: (set_id: String, similarity: Float) -> void
|
Instance Attribute Details
#set_id ⇒ String
Identifier of the matched reference set.
112 |
# File 'lib/safety_kit/models/content_create_response.rb', line 112 required :set_id, String |
#similarity ⇒ Float
Similarity between the submitted content and the matched reference set entry.
118 |
# File 'lib/safety_kit/models/content_create_response.rb', line 118 required :similarity, Float |
Instance Method Details
#to_hash ⇒ { set_id: String, similarity: Float }
82 |
# File 'sig/safety_kit/models/content_create_response.rbs', line 82
def to_hash: -> { set_id: String, similarity: Float }
|