Class: SafetyKit::Models::DeletionRequestCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/safety_kit/models/deletion_request_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(subject_user_id:, external_request_id: nil, requested_at: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see SafetyKit::Models::DeletionRequestCreateParams for more details.

Parameters:

  • subject_user_id (String)

    Your stable canonical identifier for the user or account whose data should be de

  • external_request_id (String) (defaults to: nil)

    Optional caller-provided request identifier for correlating the deletion request

  • requested_at (Time) (defaults to: nil)

    The time the deletion request was received in your system, as an ISO 8601 dateti

  • request_options (SafetyKit::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/safety_kit/models/deletion_request_create_params.rb', line 31

Instance Attribute Details

#external_request_idString?

Optional caller-provided request identifier for correlating the deletion request in both systems.

Returns:

  • (String, nil)


22
# File 'lib/safety_kit/models/deletion_request_create_params.rb', line 22

optional :external_request_id, String

#requested_atTime?

The time the deletion request was received in your system, as an ISO 8601 datetime string.

Returns:

  • (Time, nil)


29
# File 'lib/safety_kit/models/deletion_request_create_params.rb', line 29

optional :requested_at, Time

#subject_user_idString

Your stable canonical identifier for the user or account whose data should be deleted.

Returns:

  • (String)


15
# File 'lib/safety_kit/models/deletion_request_create_params.rb', line 15

required :subject_user_id, String