Class: SafetyKit::Models::DeletionRequestCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::DeletionRequestCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/safety_kit/models/deletion_request_create_params.rb
Overview
Instance Attribute Summary collapse
-
#external_request_id ⇒ String?
Optional caller-provided request identifier for correlating the deletion request in both systems.
-
#requested_at ⇒ Time?
The time the deletion request was received in your system, as an ISO 8601 datetime string.
-
#subject_user_id ⇒ String
Your stable canonical identifier for the user or account whose data should be deleted.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(subject_user_id:, external_request_id: nil, requested_at: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see DeletionRequestCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(subject_user_id:, external_request_id: nil, requested_at: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::DeletionRequestCreateParams for more details.
|
|
# File 'lib/safety_kit/models/deletion_request_create_params.rb', line 31
|
Instance Attribute Details
#external_request_id ⇒ String?
Optional caller-provided request identifier for correlating the deletion request in both systems.
22 |
# File 'lib/safety_kit/models/deletion_request_create_params.rb', line 22 optional :external_request_id, String |
#requested_at ⇒ Time?
The time the deletion request was received in your system, as an ISO 8601 datetime string.
29 |
# File 'lib/safety_kit/models/deletion_request_create_params.rb', line 29 optional :requested_at, Time |
#subject_user_id ⇒ String
Your stable canonical identifier for the user or account whose data should be deleted.
15 |
# File 'lib/safety_kit/models/deletion_request_create_params.rb', line 15 required :subject_user_id, String |