Class: SafetyKit::Models::DeletionRequestCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::DeletionRequestCreateResponse
- Defined in:
- lib/safety_kit/models/deletion_request_create_response.rb,
sig/safety_kit/models/deletion_request_create_response.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#deletion_request_id ⇒ String
SafetyKit correlation identifier for the deletion request.
-
#external_request_id ⇒ String?
Caller-provided request identifier, if supplied.
-
#status ⇒ Symbol, SafetyKit::Models::DeletionRequestCreateResponse::Status
Deletion request was accepted and queued for asynchronous processing.
Instance Method Summary collapse
-
#initialize(deletion_request_id:, status:, external_request_id: nil) ⇒ Object
constructor
Response returned after SafetyKit accepts and queues a deletion request.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(deletion_request_id:, status:, external_request_id: nil) ⇒ Object
Response returned after SafetyKit accepts and queues a deletion request.
|
|
# File 'lib/safety_kit/models/deletion_request_create_response.rb', line 25
|
Instance Attribute Details
#deletion_request_id ⇒ String
SafetyKit correlation identifier for the deletion request.
11 |
# File 'lib/safety_kit/models/deletion_request_create_response.rb', line 11 required :deletion_request_id, String |
#external_request_id ⇒ String?
Caller-provided request identifier, if supplied.
23 |
# File 'lib/safety_kit/models/deletion_request_create_response.rb', line 23 optional :external_request_id, String |
#status ⇒ Symbol, SafetyKit::Models::DeletionRequestCreateResponse::Status
Deletion request was accepted and queued for asynchronous processing.
17 |
# File 'lib/safety_kit/models/deletion_request_create_response.rb', line 17 required :status, enum: -> { SafetyKit::Models::DeletionRequestCreateResponse::Status } |
Instance Method Details
#to_hash ⇒ {
25 |
# File 'sig/safety_kit/models/deletion_request_create_response.rbs', line 25
def to_hash: -> {
|