Class: SafetyKit::Models::StreamAddFrameParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SafetyKit::Models::StreamAddFrameParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/safety_kit/models/stream_add_frame_params.rb
Overview
Instance Attribute Summary collapse
-
#image_data_uri ⇒ String
A data URI containing a base64-encoded frame image.
-
#namespace ⇒ String
The namespace to ingest stream data into.
- #stream_id ⇒ String
- #timestamp ⇒ Integer
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(namespace:, image_data_uri:, stream_id:, timestamp:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see StreamAddFrameParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(namespace:, image_data_uri:, stream_id:, timestamp:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SafetyKit::Models::StreamAddFrameParams for more details.
|
|
# File 'lib/safety_kit/models/stream_add_frame_params.rb', line 35
|
Instance Attribute Details
#image_data_uri ⇒ String
A data URI containing a base64-encoded frame image. Only image/jpeg, image/png, and image/webp are accepted. The decoded bytes must match the declared mime type, decode as a valid image, stay within 5 MB, and stay within 4096x4096 / 16,000,000 total pixels.
23 |
# File 'lib/safety_kit/models/stream_add_frame_params.rb', line 23 required :image_data_uri, String |
#namespace ⇒ String
The namespace to ingest stream data into
14 |
# File 'lib/safety_kit/models/stream_add_frame_params.rb', line 14 required :namespace, String |
#stream_id ⇒ String
28 |
# File 'lib/safety_kit/models/stream_add_frame_params.rb', line 28 required :stream_id, String |
#timestamp ⇒ Integer
33 |
# File 'lib/safety_kit/models/stream_add_frame_params.rb', line 33 required :timestamp, Integer |